@@ -18,6 +18,8 @@ extern "C" {
 #define FFT_MAX     8192
 #define FFT_LEFT     100
 #define FFT_RIGHT  10000
+#define DB_MAX       0.0
+#define DB_MIN    -100.0
 
 /* ---------------------------------------------------------------------- */
 
@@ -36,6 +38,7 @@ FFTWindow::FFTWindow(QWidget *parent, char *name) : QWidget(parent,name,0)
     /* flag: no init so far... */
     channels = 0;
     logmap = NULL;
+    ylog = false;
 }
 
 void
@@ -146,12 +149,18 @@ FFTWindow::drawhist()
             ab = re*re+im*im;
             if (ab > max)
                 max = ab;
+
             j++;
         } while (j < logmap[i+1]);
-        max = (int)(sqrt(max) * h / FFT_MAX);
+        if (ylog) {
+            float dBVal = 20 * log10( sqrt(max)/FFT_MAX );
+            max = (int)( h * ( dBVal-DB_MIN )/( DB_MAX-DB_MIN ));
+        } else {
+            max = (int)(sqrt(max) * h / FFT_MAX);
+        }
         segments[i].y1 = h-max;
     }
-    
+
     gcval.foreground = back;
     XChangeGC(x11Display(),gc,GCForeground,&gcval);
     XFillRectangle(x11Display(),winId(),gc,0,0,width(),height());
@@ -159,7 +168,12 @@ FFTWindow::drawhist()
     gcval.foreground = fore;
     XChangeGC(x11Display(),gc,GCForeground,&gcval);
     XDrawSegments(x11Display(),winId(),gc,segments,w);
-    max = height() - lmax*height()/32768;
+    if (ylog) {
+	float dBVal = 20 * log10( (double)lmax/32768 );
+	max = h - (int)( h * ( dBVal-DB_MIN )/( DB_MAX-DB_MIN ));
+    } else {
+	max = height() - lmax*height()/32768;
+    }
     XDrawLine(x11Display(),winId(),gc,0,max,width(),max);
 }
 
@@ -196,3 +210,9 @@ FFTWindow::new_data(void *data)
     drawhist();
 }
 
+void
+FFTWindow::set_ylog(int linear)
+{
+    ylog = (linear==0);
+    drawhist();
+}
