@@ -16,6 +16,7 @@ public:
 public slots:
     void new_params(struct SOUNDPARAMS *params);
     void new_data(void *data);
+    void set_ylog(int linear);
 
 protected:
     void resizeEvent(QResizeEvent *event);
@@ -29,6 +30,7 @@ private:
 
     int            afmt,channels,rate;
     int            audio_size, fft_size, lmax;
+    bool           ylog;
     
     void make_logmap();
     void calculate(unsigned char *data);
