@@ -12,6 +12,7 @@
 #include <qtooltip.h>
 #include <qlayout.h>
 #include <qbuttongroup.h>
+#include <qhbuttongroup.h>
 #include <qradiobutton.h>
 #include <qaccel.h>
 #include <qmenubar.h>
@@ -436,12 +437,33 @@ void KRecord::dragEnterEvent(QDragEnterEvent* event)
 KFFT::KFFT(Soundcard *card) : KMainWindow(0,"fft",WType_TopLevel)
 {
     int     i = -1;
-    fftwin    = new FFTWindow(this,"fft");
-    setCentralWidget(fftwin);
+
+    QWidget* centralWidget = new QWidget(this);
+    setCentralWidget(centralWidget);
+
+    QVBoxLayout *topLayout = new QVBoxLayout(centralWidget,0); 
+
+    /* button group #1 */
+    QButtonGroup* linLogGroup = new QHButtonGroup( centralWidget, "LinLogGroup" );
+    topLayout->addWidget(linLogGroup,0);
+
+    QRadioButton* rb1 = new QRadioButton( linLogGroup );
+    rb1->setText( i18n("L&og") );
+    QToolTip::add( rb1, i18n("Logarithmic Y scale") );
+
+    QRadioButton* rb2 = new QRadioButton( linLogGroup );
+    rb2->setText( i18n("L&inear") );
+    rb2->setChecked( TRUE );
+    QToolTip::add( rb2, i18n("Linear Y scale") );
+
+    fftwin    = new FFTWindow(centralWidget,"fft");
+    topLayout->addWidget(fftwin,1);
     QObject::connect(card,SIGNAL(senddata(void*)),
-		     fftwin, SLOT(new_data(void*)));
+                     fftwin, SLOT(new_data(void*)));
     QObject::connect(card,SIGNAL(newparams(struct SOUNDPARAMS*)),
-		     fftwin, SLOT(new_params(struct SOUNDPARAMS*)));
+                     fftwin, SLOT(new_params(struct SOUNDPARAMS*)));
+    QObject::connect(linLogGroup, SIGNAL(clicked(int)),
+		     fftwin, SLOT(set_ylog(int)) );
 
     setCaption("freq spectrum");
 
