@@ -2,7 +2,7 @@
 #define OSS_H
 
 #include <qobject.h>
-#include <qsocknot.h>
+#include <qsocketnotifier.h>
 
 /* ---------------------------------------------------------------------- */
 
@@ -43,7 +43,7 @@ private:
     void close_dev();
 
 public:
-    Soundcard(char *dev);
+    Soundcard(const char *dev);
     ~Soundcard();
     char *driver();
     void setparams(struct SOUNDPARAMS *params);
