@@ -24,7 +24,7 @@ extern KLocale      *globalKlocale;
 /* ------------------------------------------------------------------------ */
 
 SoundOptions::SoundOptions(Soundcard *c, const char *name)
-    : KMainWindow(0,name)
+    : KMainWindow(0,name,WType_TopLevel)
 {
     static char *rates[] = {
 	"8000","11025","16000","22050","32000","44100","48000",NULL};
